@@ -1,10 +1,10 @@
-__version__ = "0.2.17"
+__version__ = "0.2.18"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.2.17)'
+__git_branch__ = '(detached from v0.2.18)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'dd696210f70268741bba011b991ba34cc8b7eaa7'
-__git_head_subject__ = "vmware patches: don't return paths instead of crashing when none found"
+__git_head_hash__ = 'e643695b568788ee4804682a250441cb733ddacd'
+__git_head_subject__ = 'fix indentation'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
